package de.intevation.flys.client.shared.model;

import java.util.List;


/**
 * The default implementation of a CollectionItem.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class DefaultCollectionItem implements CollectionItem {

    /** The identifier that specifies the artifact related to this item.*/
    protected String identifier;

    /** The list of output modes supported by the artifact of this item.*/
    protected List<OutputMode> outputModes;


    /**
     * An empty constructor.
     */
    public DefaultCollectionItem() {
    }


    /**
     * The default constructor to create a new CollectionItem related to an
     * artifact with output modes.
     *
     * @param identifier The identifier of an artifact.
     * @param outputModes The output modes supported by this item.
     */
    public DefaultCollectionItem(String identifier, List<OutputMode> modes) {
        this.identifier  = identifier;
        this.outputModes = modes;
    }


    public String identifier() {
        return identifier;
    }


    public List<OutputMode> getOutputModes() {
        return outputModes;
    }


    public List<Facet> getFacets(String outputmode) {
        for (OutputMode mode: outputModes) {
            if (outputmode.equals(mode.getName())) {
                // TODO Return facets, but facets are not implemented for
                // OutputModes yet!
            }
        }

        return null;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
